Received: from malur.postgresql.org ([217.196.149.56]) by arkaria.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1f8puC-00031U-DS for pgsql-hackers@arkaria.postgresql.org; Wed, 18 Apr 2018 16:26:00 +0000 Received: from localhost ([127.0.0.1] helo=malur.postgresql.org) by malur.postgresql.org with esmtp (Exim 4.89) (envelope-from ) id 1f8puB-0007X5-0X for pgsql-hackers@arkaria.postgresql.org; Wed, 18 Apr 2018 16:25:59 +0000 Received: from magus.postgresql.org ([2a02:c0:301:0:ffff::29]) by malur.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1f8puA-0007Ww-Op for pgsql-hackers@lists.postgresql.org; Wed, 18 Apr 2018 16:25:58 +0000 Received: from post.visena.com ([46.226.10.50]) by magus.postgresql.org with esmtps (TLS1.2:DHE_RSA_AES_256_CBC_SHA1:256) (Exim 4.89) (envelope-from ) id 1f8pu3-0003OQ-CS for pgsql-hackers@lists.postgresql.org; Wed, 18 Apr 2018 16:25:58 +0000 DKIM-Signature: v=1; a=rsa-sha256; q=dns/txt; c=relaxed/relaxed; d=visena.com; s=20141101.wh; h=Content-Type:MIME-Version:Subject:In-Reply-To:Message-ID:To:From:Date; bh=uEORoKiH9JuHqo65qRe53VtxONui0tHVs2zFOQqaucQ=; b=SNcHHbB02xw4fB/sHY1NJVtRC0mMCgNDYfNMlFYf9M76KFjvWsiDJ1xZiI7exopXI+BUUxdRPLI5mBEzEMpe7nNXj625fhkUSpDCfnWf2REXTjaK1d1KN16njMatDC8wRUyIPWbeU+KU4lVQvt0Jo7bI40eOnpjiydxswfsrDtQ=; Received: from [10.0.1.10] (helo=tc7-visena.wh.internal.visena.com) by post.visena.com with esmtp (Exim 4.82) (envelope-from ) id 1f8pu0-00037m-Ti for pgsql-hackers@lists.postgresql.org; Wed, 18 Apr 2018 18:25:50 +0200 Received: from localhost ([127.0.0.1] helo=tc7-visena.wh.internal.visena.com) by tc7-visena.wh.internal.visena.com with esmtp (Exim 4.86_2) (envelope-from ) id 1f8puF-00059X-Ow for pgsql-hackers@lists.postgresql.org; Wed, 18 Apr 2018 18:26:03 +0200 Date: Wed, 18 Apr 2018 18:26:03 +0200 (CEST) From: Andreas Joseph Krogh To: pgsql-hackers@lists.postgresql.org Message-ID: In-Reply-To: <20180418155055.gawfkerzvy5rxpxe@alap3.anarazel.de> Subject: Sv: Re: Query is over 2x slower with jit=on MIME-Version: 1.0 Content-Type: multipart/mixed; boundary="----=_Part_155_264913208.1524068763648" X-Mailer: Visena Mail 2.1.34 X-Spam-Score: 0.0 X-Spam-Report: SpamAssasin (score=0.0, required 5.0 ALL_TRUSTED=-1,HTML_IMAGE_ONLY_20=0.7,HTML_MESSAGE=0.001,HTML_SHORT_LINK_IMG_3=0.328) List-Id: List-Help: List-Subscribe: List-Post: List-Owner: List-Archive: Precedence: bulk ------=_Part_155_264913208.1524068763648 Content-Type: multipart/related; boundary="----=_Part_156_1917926382.1524068763648" ------=_Part_156_1917926382.1524068763648 Content-Type: multipart/alternative; boundary="----=_Part_157_1507399517.1524068763671" ------=_Part_157_1507399517.1524068763671 Content-Type: text/plain; charset=UTF-8 Content-Transfer-Encoding: quoted-printable P=C3=A5 onsdag 18. april 2018 kl. 17:50:55, skrev Andres Freund >: On 2018-04-18 17:35:31 +0200, Andreas Joseph Krogh wrote: > With jit=3Don: > https://explain.depesz.com/s/vYB > Planning Time: 0.336 ms >=C2=A0 JIT: >=C2=A0 =C2=A0Functions: 716 >=C2=A0 =C2=A0Generation Time: 78.404 ms >=C2=A0 =C2=A0Inlining: false >=C2=A0 =C2=A0Inlining Time: 0.000 ms >=C2=A0 =C2=A0Optimization: false >=C2=A0 =C2=A0Optimization Time: 43.916 ms >=C2=A0 =C2=A0Emission Time: 600.031 ms Any chance this is a debug LLVM build? > What's the deal with jit making it slower? JIT has cost, and sometimes it's not beneficial. Here our heuristics when to JIT appear to be a bit off. In the parallel world it's worse because the JITing is duplicated for parallel workers atm. =C2=A0 PostgreSQL is built with "--enable-debug --with-llvm". LLVM is the one whic= h=20 comes with Ubuntu-17.10. =C2=A0 -- Andreas Joseph Krogh CTO / Partner - Visena AS Mobile: +47 909 56 963 andreas@visena.com www.visena.com =C2=A0 ------=_Part_157_1507399517.1524068763671 Content-Type: text/html;charset=UTF-8 Content-Transfer-Encoding: quoted-printable
P=C3=A5 onsdag 18. april 2018 kl. 17:50:55, skrev Andres Freund <andres@anarazel.de>:
On = 2018-04-18 17:35:31 +0200, Andreas Joseph Krogh wrote:
> With jit=3Don:
> https://explain.depesz.com/s/vYB
> Planning Time: 0.336 ms
>=C2=A0 JIT:
>=C2=A0 =C2=A0Functions: 716
>=C2=A0 =C2=A0Generation Time: 78.404 ms
>=C2=A0 =C2=A0Inlining: false
>=C2=A0 =C2=A0Inlining Time: 0.000 ms
>=C2=A0 =C2=A0Optimization: false
>=C2=A0 =C2=A0Optimization Time: 43.916 ms
>=C2=A0 =C2=A0Emission Time: 600.031 ms

Any chance this is a debug LLVM build?


> What's the deal with jit making it slower?

JIT has cost, and sometimes it's not beneficial. Here our heuristics
when to JIT appear to be a bit off. In the parallel world it's worse
because the JITing is duplicated for parallel workers atm.
=C2=A0
PostgreSQL is built with "--enable-debug --with-llvm". LLVM = is the one which comes with Ubuntu-17.10.
=C2=A0
">
--
Andrea= s Joseph Krogh
CTO / Partner<= /span> - Visena AS
Mobile: +47 90= 9 56 963
=3D""
=C2=A0
------=_Part_157_1507399517.1524068763671-- ------=_Part_156_1917926382.1524068763648 Content-Type: image/png Content-Transfer-Encoding: base64 Content-Disposition: inline Content-ID: iVBORw0KGgoAAAANSUhEUgAAAIUAAAAYCAYAAADUIj6hAAAABHNCSVQICAgIfAhkiAAABzBJREFU aEPtmNFxHDcMhmVP3i1VECpvnjzkVIHWFfhcgVcVRKrAUgWRK/C6Al8H3lTgy0PGbzFdQc4VJP/H ADs43q6kROeJNbOYgQACIAgCWJKng4MZ5gxUGXh0U0b+SIuF9G+EWXj2Q15vbrE/NPtk9uub7Gfd t5mBx1NhqSEo8HshjbEUtlO2yIM9tsx5dZP9rPt2MzDZFAqZE4LGcFjdsg3saQaHt7fY70X949On aS+OZidDBkavD33157L4xaw2os+Mp/DAC10l2XhOCeStj0W5ajrJL8WfCi80Xgf9vVlrhg9yRONe /f7xI2vNsIcM7JwU9o6oGyJrLT8JOA1aX9sKP4wl94bAniukEbo/n7YPmuTETzIab4Y9ZWCrKexd 8M58lxPCvvD6aihfvexbEQoPYO8NQRO0JnddGO6FJYaVsBde7cXj7KRk4LsqDxQzCYeGsJNgaXZe +JXkyGgWINq3Gp+bHNILz+wEYs5qH1eJrouNrpDXtk4O6x1IvtD40GWyJYYdkF0jIbYZlN16xygI gl9smbMDsmFdfAKb23xGB8H/mv3tOJfArs1kukk79DEPdQ5u0g1vCvvqKXIW8mZYW+F3Tg4r8HvZ kQCCLydK8EFMQCe5N8RgL9mRG0SqQFuNvdE6beSs0qPDBuCdg0+gvClso8SbTO4ki7mQzQqBrcMH QPwReg2wW8umEe/+L8T/LEzBGF9nXjzZ46s+ITHvhegW8LL39xm6App7KYL/GE+vcYnFbJiP/0aY hdiCnRC7jaj7eiK2ETInC5PRF6LYkSN0+HabF75WuT6syCyI0YkVGGMvUC33AmfZTDUEj8u6IVhu EhRUJ2U2g6UlugyNb03Hl9obHwlxJbcRzcYjO4QPjVfGFTQav4vrmp7cpMp2qbHnBxWJbisbho2Q XI6C1sIHDUFhH4Hij4UbIev66eANeiwbkA+LBsO36zAHzoXU7AhbqLAXEiOYTXcSdO8VS9L4wN8U BIYhBd6oSUgYMijOkecRuTdQa/YiBXhbXFcnCnI2SrfeBG9NydrLYMhGHa5qB9pQIxlzAE6Okjzx JO5afGe6kmhBicWKQNKuTZ5EW+MjQY8v/9rQ0bhJSJyNGUe/JH1t8h1iMbdSPAvxHYin6YmN9YBX QmTYZZNh14vHhhhal5vtcIrJjmvszPRJdExH3MWHvykoBEc9CoCGWJisOLOGoCORs1FvIMbYA8z3 kwM59oemy6LlWrLxFLmWgiQAfEGd8S+NssbK+EhyGLxUkhhiy717waBqHOJYSEacwBejkFNhjJNj v/gANOdQxPfciP/JVBCK2cOIcg3RRJ+CPrLPNVhhN6F38VKMF3XLlIJrjU5C8gMFxvKDvOcPc4rV NjCn7KM0BV+161V8viSCuJZ8SITGJGEh7IUUlxOFMYUH1kJOCN4Wh+I5pqCuK01k40kSNtnKiKIl UfxAgW5sU5JlS05rtt5YFJF1SWoqHv6BRgQcA4/bdb9WRjmMk3jyUMAbIoyJq9e4cVmgzKt9j5gN J/aYDhk+hhjExwaPcz5PObA5Zd9bvz5UzCTZuZDidu5AchpiKSwPR+TV1bCWqBQ9nCjJ5neivC82 Nr4LeS2j1gw5LUqwBuhGQQU5UwHeSslXkwIynz2U2A2yKDgG7OffwLA3TpGRpk0Tzpj3ZEJXi/GR a6GN0e0NtppChePdcAz1FTS+FN8Kpxoiykk+J8fC5tenjbu9kSqpHLu9jBrhUuhNwVGbpyZrzrl0 HPVD8SXj5EOOD/eDC64VjvYBZLuUbIVAfBN1t/C/SU+cAGtdGo+fVnzycUX5wmn6eCKPmWYJG2E/ ppTsuRCbvUD9fwquksG5GqLVKhzDQ3GrEyLKSXhsiK3T5j9EyxffCFOYi2wUlPyFFDQAhehESDjQ GoX0ho0oj8RPou6TxHJdcT0NTcWkO0AnG7+uXsnHqcas/72wvWF+mSf7N/Watp9kTXoluzeS0fB9 9CcZ/hvhSZTfh99pispZOXL9KrGrARkNUMu9ITbScZWs7xOYNt9pwxSZtYDsX/GE3xTkrXgwAsXm fud08FiTeC+m2/o7ppo+PTS/NBK5ARpDG5YHr++DpmVfreYdiX8mnp+DzPEG9WbqJON0JBenZofs sxBA1gj5NXGvfJu/Qh7HwQh/VDUEyUxCit5hH94QfKkEdu+GwK8BX0hvCF+D67xhjmXQCXMwJCZ+ olK0A1EKRCE4snsh42w8Mv/Zhxw9iD7Cjo7CyQC/KyF6oBfShL4PYgG+CHsYKyZxvxZSZBAgjhIz YDz+AbfD37GtbaoSKzgGt+lKfI/GZtay6vG4VXTpPsh+IcQhOk9I7WYeP5AM3HZ9+DaSGIp9HIuu huC4pCGGx+YD2fcc5tfIAA0h/Et4/jX8zz4fWAasIf4UbR9Y6HO4d8jAnd4U0Y8ageuCB+c+H5R3 CHU2mTMwZ+B/y8DfSMBLLOYXVuEAAAAASUVORK5CYII= ------=_Part_156_1917926382.1524068763648-- ------=_Part_155_264913208.1524068763648--